@@ -1,9 +1,9 @@
 package Role::TinyCommons::Collection::GetItemByKey;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-07'; # DATE
+our $DATE = '2021-05-20'; # DATE
 our $DIST = 'Role-TinyCommons-Collection'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use Role::Tiny;
 
@@ -13,6 +13,11 @@ requires 'get_item_at_key';
 requires 'has_item_at_key';
 requires 'get_all_keys';
 
+### provides
+
+# alias for has_item_at_key
+sub has_key { my $self = shift; $self->has_item_at_key(@_) }
+
 1;
 # ABSTRACT: Locating an item by a key
 
@@ -28,7 +33,7 @@ Role::TinyCommons::Collection::GetItemByKey - Locating an item by a key
 
 =head1 VERSION
 
-This document describes version 0.007 of Role::TinyCommons::Collection::GetItemByKey (from Perl distribution Role-TinyCommons-Collection), released on 2021-05-07.
+This document describes version 0.008 of Role::TinyCommons::Collection::GetItemByKey (from Perl distribution Role-TinyCommons-Collection), released on 2021-05-20.
 
 =head1 SYNOPSIS
 
@@ -54,7 +59,8 @@ Usage:
 
  my $has_item = $obj->has_item_at_key($key); # => bool
 
-Check whether the collection has item at key C<$key>.
+Check whether the collection has item at key C<$key>. In Perl, this is
+equivalent to doing C<exists()> on a hash.
 
 =head2 get_all_keys
 
@@ -64,6 +70,12 @@ Usage:
 
 Return all known keys. Note that a specific order is not required.
 
+=head1 PROVIDED METHODS
+
+=head2 has_key
+
+Alias for L</has_item_at_key>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyCommons-Collection>.
